@@ -369,8 +369,10 @@ class ClUpdateAction(Action):
              },
          ]
         },
-        {'name': 'update:set_upto_date_cache',
-         'method': 'Update.setUpToDateCache()'
+        {'name': 'set_upto_date_cache',
+         'method': 'Update.setUpToDateCache()',
+         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off' and \
+                                  Get('cl_update_pretend_set') == 'off'
         }
     ]
 
